@@ -263,6 +263,56 @@ BUILTIN_THEMES: dict[str, Theme] = {
             "button-color-foreground": "#EFF1F5",
         },
     ),
+    "catppuccin-frappe": Theme(
+        name="catppuccin-frappe",
+        primary="#CA9EE6",
+        secondary="#EF9F76",
+        warning="#E5C890",
+        error="#E78284",
+        success="#A6D189",
+        accent="#F4B8E4",
+        foreground="#C6D0F5",
+        background="#303446",
+        surface="#414559",
+        panel="#51576D",
+        dark=True,
+        variables={
+            "input-cursor-foreground": "#232634",
+            "input-cursor-background": "#F2D5CF",
+            "input-selection-background": "#949CBB 30%",
+            "border": "#BABBF1",
+            "border-blurred": "#838BA7",
+            "footer-background": "#51576D",
+            "block-cursor-foreground": "#292C3C",
+            "block-cursor-text-style": "none",
+            "button-color-foreground": "#303446",
+        },
+    ),
+    "catppuccin-macchiato": Theme(
+        name="catppuccin-macchiato",
+        primary="#C6A0F6",
+        secondary="#F5A97F",
+        warning="#EED49F",
+        error="#ED8796",
+        success="#A6DA95",
+        accent="#F5BDE6",
+        foreground="#CAD3F5",
+        background="#24273A",
+        surface="#363A4F",
+        panel="#494D64",
+        dark=True,
+        variables={
+            "input-cursor-foreground": "#181926",
+            "input-cursor-background": "#F4DBD6",
+            "input-selection-background": "#838BA7 30%",
+            "border": "#B7BDF8",
+            "border-blurred": "#737994",
+            "footer-background": "#494D64",
+            "block-cursor-foreground": "#1E2030",
+            "block-cursor-text-style": "none",
+            "button-color-foreground": "#24273A",
+        },
+    ),
     "solarized-light": Theme(
         name="solarized-light",
         primary="#268bd2",
