@@ -96,7 +96,7 @@ class FooterKey(Widget):
         if disabled:
             classes += " -disabled"
         super().__init__(classes=classes)
-        self.shrink = False
+        self.set_reactive(Widget.shrink, False)
         if tooltip:
             self.tooltip = tooltip
 
@@ -260,7 +260,8 @@ class Footer(ScrollableContainer, can_focus=False, can_focus_children=False):
             disabled=disabled,
         )
         self.set_reactive(Footer.show_command_palette, show_command_palette)
-        self.compact = compact
+        self.set_reactive(Footer.compact, compact)
+        self.set_class(compact, "-compact", update=False)
 
     def compose(self) -> ComposeResult:
         if not self._bindings_ready:
